/*
 * Paraselene
 * Copyright (c) 2009  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene.mockup;


public class TagException extends Exception {
	TagException( String s) {
		super( s );
	}

	TagException( Throwable e ) {
		super( e );
	}
}

